//
//  ContentView.swift
//  OnOpenURLDemo
//
//  Created by Gabriel Theodoropoulos.
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State private var importedNote: Note?
    
    var body: some View {
        Group {
            // If a note was imported and importedNote is not nil,
            // then show the note title and body.
            if let note = importedNote {
                VStack(alignment: .leading, spacing: 20) {
                    Text(note.title)
                        .font(.title)
                        .fontWeight(.semibold)
                    
                    Text(note.body)
                        .font(.body)
                        .foregroundColor(.secondary)
                    
                    Spacer()
                }
                .padding()
            } else {
                // If no note was imported, show just a message
                // with an icon.
                ContentUnavailableView("No note imported yet!",
                                       systemImage: "doc.text")
            }
        }
        .onReceive(NotificationCenter.default.publisher(for: .didImportNote)) { notification in
            guard let note = notification.object as? Note else { return }
            importedNote = note
        }
    }
}

#Preview {
    ContentView()
}
